@@ -14,32 +14,11 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-package Dpkg::Control::HashCore;
-
-use strict;
-use warnings;
-
-our $VERSION = '1.02';
-
-use Dpkg::Gettext;
-use Dpkg::ErrorHandling;
-use Dpkg::Control::FieldsCore;
-
-# This module cannot use Dpkg::Control::Fields, because that one makes use
-# of Dpkg::Vendor which at the same time uses this module, which would turn
-# into a compilation error. We can use Dpkg::Control::FieldsCore instead.
-
-use parent qw(Dpkg::Interface::Storable);
-
-use overload
-    '%{}' => sub { ${$_[0]}->{fields} },
-    'eq' => sub { "$_[0]" eq "$_[1]" };
-
 =encoding utf8
 
 =head1 NAME
 
-Dpkg::Control::HashCore - parse and manipulate a block of RFC822-like fields
+Dpkg::Control::HashCore - parse and manipulate a stanza of deb822 fields
 
 =head1 DESCRIPTION
 
@@ -61,6 +40,28 @@ modified. Empty lines and lines containing only dots are prefixed with
 During parsing, trailing spaces are stripped on all lines while leading
 spaces are stripped only on the first line of each field.
 
+=cut
+
+package Dpkg::Control::HashCore 1.02;
+
+use strict;
+use warnings;
+
+use Dpkg::Gettext;
+use Dpkg::ErrorHandling;
+use Dpkg::Control::FieldsCore;
+use Dpkg::Control::HashCore::Tie;
+
+# This module cannot use Dpkg::Control::Fields, because that one makes use
+# of Dpkg::Vendor which at the same time uses this module, which would turn
+# into a compilation error. We can use Dpkg::Control::FieldsCore instead.
+
+use parent qw(Dpkg::Interface::Storable);
+
+use overload
+    '%{}' => sub { ${$_[0]}->{fields} },
+    'eq' => sub { "$_[0]" eq "$_[1]" };
+
 =head1 METHODS
 
 =over 4
@@ -176,9 +177,9 @@ Prints an error message and dies on syntax parse errors.
 =cut
 
 sub parse_error {
-    my ($self, $file, $msg) = (shift, shift, shift);
+    my ($self, $file, $msg, @args) = @_;
 
-    $msg = sprintf($msg, @_) if (@_);
+    $msg = sprintf $msg, @args if @args;
     error(g_('syntax error in %s at line %d: %s'), $file, $., $msg);
 }
 
@@ -205,7 +206,7 @@ sub parse {
     while (<$fh>) {
         # In the common case there will be just a trailing \n character,
         # so using chomp here which is very fast will avoid the latter
-        # s/// doing anything, which gives usa significant speed up.
+        # s/// doing anything, which gives us a significant speed up.
 	chomp;
         my $armor = $_;
         s/\s+$//;
@@ -277,7 +278,8 @@ sub parse {
 		# be verified by an OpenPGP backend.
 		$$self->{is_pgp_signed} = 1;
 	    }
-	    last; # Finished parsing one block
+            # Finished parsing one stanza.
+            last;
         } elsif ($armor =~ m/^-----BEGIN PGP SIGNED MESSAGE-----[\r\t ]*$/) {
             $expect_pgp_sig = 1;
             if ($$self->{allow_pgp} and not $parabody) {
@@ -463,110 +465,6 @@ sub apply_substvars {
     }
 }
 
-package Dpkg::Control::HashCore::Tie;
-
-# This class is used to tie a hash. It implements hash-like functions by
-# normalizing the name of fields received in keys (using
-# Dpkg::Control::Fields::field_capitalize). It also stores the order in
-# which fields have been added in order to be able to dump them in the
-# same order. But the order information is stored in a parent object of
-# type Dpkg::Control.
-
-use strict;
-use warnings;
-
-use Dpkg::Control::FieldsCore;
-
-use Carp;
-use Tie::Hash;
-use parent -norequire, qw(Tie::ExtraHash);
-
-# $self->[0] is the real hash
-# $self->[1] is a reference to the hash contained by the parent object.
-# This reference bypasses the top-level scalar reference of a
-# Dpkg::Control::Hash, hence ensuring that reference gets DESTROYed
-# properly.
-
-# Dpkg::Control::Hash->new($parent)
-#
-# Return a reference to a tied hash implementing storage of simple
-# "field: value" mapping as used in many Debian-specific files.
-
-sub new {
-    my $class = shift;
-    my $hash = {};
-    tie %{$hash}, $class, @_; ## no critic (Miscellanea::ProhibitTies)
-    return $hash;
-}
-
-sub TIEHASH  {
-    my ($class, $parent) = @_;
-    croak 'parent object must be Dpkg::Control::Hash'
-        if not $parent->isa('Dpkg::Control::HashCore') and
-           not $parent->isa('Dpkg::Control::Hash');
-    return bless [ {}, $$parent ], $class;
-}
-
-sub FETCH {
-    my ($self, $key) = @_;
-    $key = lc($key);
-    return $self->[0]->{$key} if exists $self->[0]->{$key};
-    return;
-}
-
-sub STORE {
-    my ($self, $key, $value) = @_;
-    $key = lc($key);
-    if (not exists $self->[0]->{$key}) {
-        push @{$self->[1]->{in_order}}, field_capitalize($key);
-    }
-    $self->[0]->{$key} = $value;
-}
-
-sub EXISTS {
-    my ($self, $key) = @_;
-    $key = lc($key);
-    return exists $self->[0]->{$key};
-}
-
-sub DELETE {
-    my ($self, $key) = @_;
-    my $parent = $self->[1];
-    my $in_order = $parent->{in_order};
-    $key = lc($key);
-    if (exists $self->[0]->{$key}) {
-	delete $self->[0]->{$key};
-	@{$in_order} = grep { lc ne $key } @{$in_order};
-	return 1;
-    } else {
-	return 0;
-    }
-}
-
-sub FIRSTKEY {
-    my $self = shift;
-    my $parent = $self->[1];
-    foreach my $key (@{$parent->{in_order}}) {
-	return $key if exists $self->[0]->{lc $key};
-    }
-}
-
-sub NEXTKEY {
-    my ($self, $last) = @_;
-    my $parent = $self->[1];
-    my $found = 0;
-    foreach my $key (@{$parent->{in_order}}) {
-	if ($found) {
-	    return $key if exists $self->[0]->{lc $key};
-	} else {
-	    $found = 1 if $key eq $last;
-	}
-    }
-    return;
-}
-
-1;
-
 =back
 
 =head1 CHANGES
